*--------------------------------------------------------------*
*                Converted with cdf2F by G.Velev               *
*--------------------------------------------------------------*
C======================================================================C
      LOGICAL FUNCTION CVLREJ(IL,KF,KC,KS,ILPA,ILD1,ILD2)
C----------------------------------------------------------------------C
C     Judge to reject the track                                        C
C     Define class number IC, string number IS, and additinal info. IA C
C----------------------------------------------------------------------C
C Input                                                                C
C     IL   = LUJETS pointer                                            C
C     KF   = KF particle id code                                       C
C     KS   = Status code                                               C
C     ILPA = LUJETS parent pointer                                     C
C     ILD1 = LUJETS 1st daughter pointer                               C
C     ILD2 = LUJETS 2nd daughter pointer                               C
C----------------------------------------------------------------------C
C Output                                                               C
C *INFOR(IL)=IC+100*IS+10000*IA                                        C
C  o Track class id                                                    C
C      IC = 1 : Beams                                                  C
C         = 2 : Hard process                                           C
C         = 3 : Parton shower                                          C
C         = 4 : Strong hadron decays                                   C
C         = 5 : Parton in heavy flavor decays                          C
C  o String number IS is n if it comes from n-th string, otherwise 0   C
C  o Additional information                                            C
C      For IC = 1 : IA = 1,2                                           C
C          IC = 2 : IA = 10,20   : Initial state from beam             C
C                      = 30,40,..: Direct final state from hard proc   C
C                      = 50      : Parton from color singlet boson     C
C                      = n*10+1  : Decayed from IA = n*10 particle     C
C                      =  90     : Intermediate boson                  C
C                      = 100     : Color singlet from hard process     C
C                                  or Color singlet from C.S. boson    C
C                      =  1      : Color singlet from final parton     C
C          IC = 3 : IA = 1,2     : Spectator hadron, parton(if IS.NE.0)C
C                      =  8      : Copy of C.S.final state in hard procC
C                      =  9      : Unexpected non-hadron from hard procC
C                      =  0      : Parent is absent, parton            C
C                      = n*10+1  : From IA=n*10(+1), parton            C
C          IC = 4 : IA =  0      : Parent is absent                    C
C                      =  1      : Decay product of hadron             C
C                      =  2      : From string                         C
C                      =  3      : String                              C
C                      =  4      : From shower                         C
C          IC = 5 : IA = 70      : Parton in heavy flavor decays       C
C----------------------------------------------------------------------C
C Revision history                                                     C
C     1990-10-04 H.Iso Original creation for PYTHIA 5.4 and JETSET 7.3 C
C----------------------------------------------------------------------C
C
      implicit none
C
C.....Arguments
      INTEGER IL,KF,KC,KS,ILPA,ILD1,ILD2
C
C.....PYTHIA/JETSET include files
#include "pythia6.inc" 
C
C.....Particle conversion table
#include "cvtlnd.inc" 
C
C.....CDF include files
#include "inc/jobsta.inc" 
#include "inc/evsp.inc" 
#include "generator/gnpack.inc" 
#include "generator/genp.inc" 
C
C.....Mappings, Track informations
      COMMON/CVLMAP/IKMAP,ILMAP,ILPAR,INFOR,ILINHD
      INTEGER IKMAP(NMXLND)   ! Mapping IL -> IK
      INTEGER ILMAP(MAXGEN)   ! Mapping IK -> IL
      INTEGER ILPAR(NMXLND)   ! Mapping IL -> Parent of IL
      INTEGER INFOR(NMXLND)   ! Mapping IK -> IC+100*IS+10000*IA
      INTEGER ILINHD(2)  ! IL of initial state which makes hard collision
C
C.....String pointer
      INTEGER MXSTRG
      PARAMETER( MXSTRG = 100 )
      INTEGER ILSTRG,NSTRNG
      COMMON/CVLSTG/NSTRNG,ILSTRG(MXSTRG,2)
C
C.....Conversion option
      LOGICAL NOPYTH,NOJETS,NOSTRG,NOUNST
      COMMON/CVLOPT/NOPYTH,NOJETS,NOSTRG,NOUNST
C
C.....Local use
      INTEGER IA,IC,IS,ILPFIN,ILSFIN,NFHARD,KFPA,NBD
      INTEGER ICCHG
      INTEGER IKPA
      LOGICAL LSFIND
C
C.....External functions
C      INTEGER PYCOMP
C
C...................................................End of declarations/
C
      CVLREJ=.FALSE.
C
C=====Initialize when IL=1
      IF(IL.EQ.1) THEN
         ILPFIN=0
         ILSFIN=0
         NFHARD=0
         NSTRNG=0
         LSFIND=.FALSE.
         NBD=0
      ENDIF
C
C=====Comment line
      IF(KS.LT.0) THEN
         CVLREJ=.TRUE.
         IKMAP(IL)=-1
         IC=0
         IS=0
         IA=0
C
C=====PYTHIA stuff
      ELSEIF(KS.EQ.21) THEN
         IS=0
         ILPFIN=IL
C--------Beams
         IF(IL.EQ.1.OR.IL.EQ.2) THEN
            IC=1
            IA=IL
C--------Parton from beams
         ELSEIF(ILPA.EQ.1.OR.ILPA.EQ.2) THEN
            IC=2
            IA=ILPA*10
C--------Parton split from a parton which comes from beams
         ELSEIF(ILPA.NE.0.AND.NFHARD.EQ.0) THEN
            IC=2
            IA=(INFOR(ILPA)/10000/10)*10+1
C--------Final state
         ELSEIF(ILPA.EQ.0) THEN
            IC=2
            NFHARD=NFHARD+1
C...........Parton
            IF(KCHG(PYCOMP(KF),2).NE.0) THEN
               IA=(2+NFHARD)*10
C...........Gamma
            ELSEIF(KF.EQ.22) THEN
               IA=100
C...........Color singlet boson
            ELSEIF(IABS(KF).GE.23.AND.IABS(KF).LE.40) THEN
               IA=90
C...........Color singlet
            ELSE
               IA=100
            ENDIF
C--------Daughter of final states
         ELSE
            IC=2
            KFPA=K(ILPA,2)
C...........From color singlet boson
            IF(IABS(KFPA).GE.22.AND.IABS(KFPA).LE.40) THEN
               INFOR(ILPA)=90*10000+MOD(INFOR(ILPA),10000)
C            * parton
               IF(KCHG(KC,2).NE.0) THEN
                  NBD=NBD+1
                  IA=(4+NBD)*10
C            * color singlet
               ELSE
                  IA=100
               ENDIF
C...........From parton
            ELSE
C            * parton
               IF(KCHG(KC,2).NE.0) THEN
                  IA=(INFOR(ILPA)/10000/10)*10+1
C            * color singlet
               ELSE
                  IA=1
               ENDIF
            ENDIF
         ENDIF
C
C=====JETSET stuff
      ELSE
C
         ICCHG=KCHG(KC,2)
C
C--------Color non-singlet
         IF(ICCHG.NE.0) THEN
C...........This track makes string
            IF(KS.EQ.1.OR.KS.EQ.2.OR.KS.EQ.11.OR.KS.EQ.12) THEN
               IF(.NOT.LSFIND) THEN
                  LSFIND=.TRUE.
                  NSTRNG=NSTRNG+1
                  ILSTRG(NSTRNG,1)=IL
               ENDIF
               IF(KS.EQ.1.OR.KS.EQ.11) THEN
                  LSFIND=.FALSE.
                  ILSTRG(NSTRNG,2)=IL
               ENDIF
               IS=NSTRNG
C...........Otherwise(?)
            ELSE
               IS=0
            ENDIF
C...........Comes from PYTHIA stuff
            IF(ILPA.LE.ILPFIN) THEN
               IC=3
               IF(ILPA.EQ.1.OR.ILPA.EQ.2) THEN
                  IA=ILPA
               ELSEIF(ILPA.NE.0) THEN
                  IA=(INFOR(ILPA)/10000/10)*10+1
               ELSE
                  IA=0
               ENDIF
C...........Heavy quark decay
            ELSE
               IC=5
               IA=70
            ENDIF
C--------Color singlet
         ELSE
C...........Shower
            IF(ILPA.LE.ILPFIN) THEN
               IC=3
               ILSFIN=IL
               IS=0
C..............No parent
               IF(ILPA.EQ.0) THEN
                  IA=0
C..............Spectator hadron
               ELSEIF(ILPA.EQ.1.OR.ILPA.EQ.2) THEN
                  IA=ILPA
C..............Copy of siglet final state of Hard process, lepton, photon,..
               ELSE
                  IF(K(ILPA,2).EQ.KF) THEN
                     CVLREJ=.TRUE.
                     IKMAP(IL)=-3
                     IA=8
                     IKPA=IKMAP(ILPA)
                     IF(IKPA.GE.1) THEN
                        IKMAP(IL)=IKPA
                        ILMAP(IKPA)=IL
                        ILPAR(IL)=ILPAR(ILPA)
                        IKMAP(ILPA)=-2
                        ILPAR(ILPA)=IL
                        IA=INFOR(ILPA)/10000
                        IS=MOD(INFOR(ILPA),10000)/100
                        IC=MOD(INFOR(ILPA),100)
                     ENDIF
                  ELSE
                     IA=9
                  ENDIF
               ENDIF
C...........Particle
            ELSE
               IC=4
C            * String or cluster
               IF(KF.EQ.92.OR.KF.EQ.91) THEN
                  IF(NOSTRG) THEN
                     CVLREJ=.TRUE.
                     IKMAP(IL)=-1
                  ENDIF
                  IS=MOD(INFOR(ILPA),10000)/100
                  IA=3
C            * Hadron
               ELSE
                  IF(ILPA.EQ.0) THEN
                     IS=0
                     IA=0
                  ELSE
                     IS=MOD(INFOR(ILPA),10000)/100
                     IF(ILPA.LE.ILSFIN) THEN
                        IA=4
                     ELSE
                        IS=MOD(INFOR(ILPA),10000)/100
                        IF(K(ILPA,2).EQ.92.OR.K(ILPA,2).EQ.91) THEN
                           IA=2
                        ELSE
                           IA=1
                        ENDIF
                     ENDIF
                  ENDIF
               ENDIF
            ENDIF
         ENDIF
      ENDIF
C
C=====Define INFOR
      INFOR(IL)=IC+100*IS+10000*IA
C
      RETURN
      END
